spec-coerce.spec.specs.alpha

This namespace is a copy of the patch in https://dev.clojure.org/jira/browse/CLJ-2112.

Please don't use it. It's private.

This namespace is a copy of the patch in
https://dev.clojure.org/jira/browse/CLJ-2112.

Please don't use it. It's private.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries